@@ -33,12 +33,10 @@
 #
 #######################################################################
 
-from __future__ import division, print_function
 import sys
 print("\nexecuting test file", __file__, file=sys.stderr)
 exec(compile(open('set_paths.py', "rb").read(), 'set_paths.py', 'exec'))
 
-from nose.tools import assert_equal, raises
 import numpy as np
 import vigra.vigranumpycore # FIXME: why is this needed? (without, impex returns ndarray)
 import vigra.impex as im
@@ -58,11 +56,11 @@ volumeFloat=at.Volume(np.random.rand(3,4,5,6)*100,dtype=np.float32,
                   axistags=at.VigraArray.defaultAxistags(4, 'C'))
 
 def checkEqualData(i1,i2):
-    assert_equal(i1.shape, i2.shape)
+    assert i1.shape == i2.shape
     assert(np.all(i1==i2))
 
 def checkUnequalData(i1,i2):
-    assert_equal(i1.shape, i2.shape)
+    assert i1.shape == i2.shape
     assert(np.any(i1!=i2))
 
 def test_multiImageTiff():
@@ -121,10 +119,10 @@ def test_writeAndReadImageHDF5():
 
     # negative tests
     # write and read image
-    image_imp[1,1,1] = 100000
+    image_imp[1,1,1] = 100
     checkUnequalData(image,image_imp)
     # write and read scalar image
-    scalar_image_imp[1,1] = 100000
+    scalar_image_imp[1,1] = 100
     checkUnequalData(scalar_image,scalar_image_imp)
 
 def test_writeAndReadVolumeHDF5():
@@ -154,8 +152,8 @@ def test_writeAndReadVolumeHDF5():
 
     # negative tests
     # write and read volume
-    volume256_imp[1,1,1] = 100000
+    volume256_imp[1,1,1] = 100
     checkUnequalData(volume256,volume256_imp)
     # write and read binary volume
-    volumeFloat_imp[1,1,1] = 100000
+    volumeFloat_imp[1,1,1] = 100
     checkUnequalData(volumeFloat.transposeToDefaultOrder(), volumeFloat_imp)
